@@ -651,8 +651,16 @@ void unpackNDll ( SV * arg, void * var, int ndims, LONGLONG *dims,
 void unpackND (SV* arg, void* var, int ndims, long *dims,
 	       int datatype, int perlyunpack)
 {
-  LONGLONG* dimsll = malloc(ndims*sizeof(LONGLONG));
+  LONGLONG* dimsll;
   int i;
+
+  if (1==ndims) {
+    unpack1D(arg, var, dims[0], datatype, perlyunpack);
+    return;
+  }
+
+  dimsll = malloc(ndims*sizeof(LONGLONG));
+
   for (i=0; i<ndims; ++i)
     dimsll[i] = dims[i];
   unpackNDll(arg, var, ndims, dimsll, datatype, perlyunpack);
